@@ -1,6 +1,6 @@
 # Copyright (c) Stephan Martin <sm@sm-zone.net>
 #
-# $Id: OpenSSL.pm,v 1.14 2006/07/13 22:36:13 sm Exp $
+# $Id: OpenSSL.pm,v 1.13 2006/06/29 21:22:28 sm Exp $
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -468,7 +468,7 @@ sub parsecrl {
          );
 
    if($ret) {
-      $t = _("Error converting CRL");
+      $t = _("Error converting CLR");
       GUI::HELPERS::print_warning($t, $ext);
       return;
    }
@@ -481,7 +481,7 @@ sub parsecrl {
          );
 
    if($ret) {
-      $t = _("Error converting CRL");
+      $t = _("Error converting CLR");
       GUI::HELPERS::print_warning($t, $ext);
       return;
    }
